searchData={"items":[{"type":"module","title":"NimbleOptionsEx","doc":"Set of custom functions to enhance the UX with `NimbleOptions`.","ref":"NimbleOptionsEx.html"},{"type":"function","title":"NimbleOptionsEx.access?/1","doc":"Validates that the term passed implements `Access` behaviour.\n\n_Example:_\n\n    iex> schema = [\n    ...>   container: [\n    ...>     required: true,\n    ...>     type: {:custom, NimbleOptionsEx, :access?, []},\n    ...>     doc: \"The implementation of `Access` to be used as a storage\"\n    ...>   ]\n    ...> ]\n    iex> NimbleOptions.validate([container: %{}], schema)\n    {:ok, [container: %{}]}\n    iex> NimbleOptions.validate([container: [foo: :bar]], schema)\n    {:ok, [container: [foo: :bar]]}\n    iex> NimbleOptions.validate([container: [1, 2, 3]], schema)\n    {:error, %NimbleOptions.ValidationError{\n      message: \"invalid value for :container option: expected a keyword list, got a list ‹[1, 2, 3]›\",\n      key: :container, value: [1, 2, 3], keys_path: []}}","ref":"NimbleOptionsEx.html#access?/1"},{"type":"function","title":"NimbleOptionsEx.behaviour/2","doc":"Validates a behaviour specified as a module or as a set of functions.\n\n_Example:_\n\n    iex> schema = [\n    ...>   container: [\n    ...>     required: true,\n    ...>     type: {:custom, NimbleOptionsEx, :behaviour, [Supervisor]},\n    ...>     doc: \"The implementation of `Supervisor` to be used as a supervisor\"\n    ...>   ]\n    ...> ]\n    iex> NimbleOptions.validate([container: DynamicSupervisor], schema)\n    {:ok, [container: DynamicSupervisor]}\n    iex> NimbleOptions.validate([container: DateTime], schema)\n    {:error, %NimbleOptions.ValidationError{\n      message: \"invalid value for :container option: module ‹DateTime› does not implement requested callbacks ‹[init: 1]›\",\n      key: :container, value: DateTime, keys_path: []}}\n\nIf no arguments are given, the checker would make sure the module\n  passed is indeed a module, available at the moment of invocation.\n\n---\n\nPlease note, that `Access` behaviour is somewhat special, because\n  it’s supported for _terms_, such as maps `%{foo: :bar}` (not `Map`,)\n  keywords `[foo: :bar]` (not `Keyword`,) and structs `%Strct{foo: :bar}`\n  (not `Strct` module itself.) Use `access?/1` validator to check\n  whether `Access` is supported _by a term itself_.","ref":"NimbleOptionsEx.html#behaviour/2"},{"type":"function","title":"NimbleOptionsEx.property/2","doc":"Validates that the term passed is a `prop`, a member of a `prop_list`.\n\n_Example:_\n\n    iex> schema = [\n    ...>   prop: [\n    ...>     required: true,\n    ...>     type: {:custom, NimbleOptionsEx, :property, [:string]},\n    ...>     doc: \"The property of type `{atom(), binary()}`\"\n    ...>   ]\n    ...> ]\n    iex> NimbleOptions.validate([prop: {:foo, \"bar\"}], schema)\n    {:ok, [prop: {:foo, \"bar\"}]}\n    iex> NimbleOptions.validate([prop: {:foo, 42}], schema)\n    {:error, %NimbleOptions.ValidationError{\n        message: \"invalid value for :prop option: invalid value for :foo option: expected string, got: 42\",\n        key: :prop, keys_path: [], value: {:foo, 42}}}","ref":"NimbleOptionsEx.html#property/2"},{"type":"extras","title":"NimbleOptionsEx","doc":"# NimbleOptionsEx [![Kantox ❤ OSS](https://img.shields.io/badge/❤-kantox_oss-informational.svg)](https://kantox.com/)  ![Test](https://github.com/am-kantox/nimble_options_ex/workflows/Test/badge.svg)  ![Dialyzer](https://github.com/am-kantox/nimble_options_ex/workflows/Dialyzer/badge.svg)","ref":"readme.html"},{"type":"extras","title":"Addons to [`NimbleOptions`](https://hexdocs.pm/nimble_options) - NimbleOptionsEx","doc":"### `behaviour/2`\n\n```elixir\nschema = [\n  container: [\n    required: true,\n    type: {:custom, NimbleOptionsEx, :behaviour, [Supervisor]},\n    doc: \"The implementation of `Supervisor` to be used as a supervisor\"\n  ]\n]\n\nNimbleOptions.validate([container: DynamicSupervisor], schema)\n#⇒ {:ok, [container: DynamicSupervisor]}\n\nNimbleOptions.validate([container: DateTime], schema)\n#⇒ {:error, %NimbleOptions.ValidationError{\n#    message: \"[…] ‹DateTime› does not implement requested callbacks ‹[init: 1]›\",\n#    key: :container, value: DateTime, keys_path: []}}\n```\n\n### `access?/1`\n\n```elixir\nschema = [\n  container: [\n    required: true,\n    type: {:custom, NimbleOptionsEx, :access?, []},\n    doc: \"The implementation of `Access` to be used as a storage\"\n  ]\n]\n\nNimbleOptions.validate([container: %{}], schema)\n#⇒ {:ok, [container: %{}]}\nNimbleOptions.validate([container: [foo: :bar]], schema)\n#⇒ {:ok, [container: [foo: :bar]]}\nNimbleOptions.validate([container: [1, 2, 3]], schema)\n#⇒ {:error, %NimbleOptions.ValidationError{\n#    message: \"[…] expected a keyword list, got a list ‹[1, 2, 3]›\",\n#    key: :container, value: [1, 2, 3], keys_path: []}}\n```","ref":"readme.html#addons-to-nimbleoptions-https-hexdocs-pm-nimble_options"},{"type":"extras","title":"Installation - NimbleOptionsEx","doc":"```elixir\ndef deps do\n  [\n    {:nimble_options_ex, \"~> 0.1\"}\n  ]\nend\n```\n\n## [Documentation](https://hexdocs.pm/nimble_options_ex)","ref":"readme.html#installation"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}